# 2022-04-13 - Child Chain Liquidity Gauge Factory

Deployment of the `ChildChainLiquidityGaugeFactory`, for liquidity gauges to be used with pools on networks other than Ethereum.

## Useful Files

- [Polygon mainnet addresses](./output/polygon.json)
- [Arbitrum mainnet addresses](./output/arbitrum.json)
- [Optimism mainnet addresses](./output/optimism.json)
- [Gnosis mainnet addresses](./output/gnosis.json)
- [Goerli testnet addresses](./output/goerli.json)
- [`ChildChainStreamer` artifact](./artifact/ChildChainStreamer.json)
- [`RewardsOnlyGauge` artifact](./artifact/RewardsOnlyGauge.json)
- [`ChildChainLiquidityGaugeFactory` artifact](./artifact/ChildChainLiquidityGaugeFactory.json)
